@@ -2,6 +2,7 @@
 定义仓库异常
 @author hujing
 """
+import traceback
 
 
 class DepotError:
@@ -10,6 +11,9 @@ class DepotError:
         :param err:
         :param tb: 堆栈信息
         """
+        if not tb:
+            tb = traceback.extract_stack()[0:-1]
+            tb = ''.join(traceback.format_list(tb))
         self._err = err
         self._traceback = tb
 
